@@ -670,7 +670,7 @@ class JOBManager(object):
                                 m_Job.finished_jobs = m_Job.finished_jobs + 1
                                 m_Job.active_jobs = m_Job.active_jobs - 1
                                 m_Job.FinishWorker(self.MetaConn, m_Worker.WorkerHandler_ID,
-                                                 m_Process.exitcode, "")
+                                                   m_Process.exitcode, "")
                                 self.SaveJob(m_Job)
                                 # 从当前保存的进程信息中释放该进程
                                 self.ProcessID.pop(m_ProcessID)
@@ -681,7 +681,7 @@ class JOBManager(object):
                                     if m_Worker.start_time + m_Job.getTimeOut() < currenttime:
                                         m_Process.terminate()
                                         m_Job.FinishWorker(self.MetaConn, m_Worker.WorkerHandler_ID,
-                                                         m_Process.exitcode, "TIMEOUT")
+                                                           m_Process.exitcode, "TIMEOUT")
                                         m_Job.failed_jobs = m_Job.failed_jobs + 1
                                         m_Job.finished_jobs = m_Job.finished_jobs + 1
                                         m_Job.active_jobs = m_Job.active_jobs - 1
@@ -692,7 +692,7 @@ class JOBManager(object):
                                         if m_Job.getStatus() == "WAITINGFOR_ABORT":
                                             m_Process.terminate()
                                             m_Job.FinishWorker(self.MetaConn, m_Worker.WorkerHandler_ID,
-                                                             m_Process.exitcode, "ABORTED")
+                                                               m_Process.exitcode, "ABORTED")
                                             m_Job.failed_jobs = m_Job.failed_jobs + 1
                                             m_Job.finished_jobs = m_Job.finished_jobs + 1
                                             m_Job.active_jobs = m_Job.active_jobs - 1
@@ -704,7 +704,7 @@ class JOBManager(object):
                                     if m_Job.getStatus() == "WAITINGFOR_ABORT":
                                         m_Process.terminate()
                                         m_Job.FinishWorker(self.MetaConn, m_Worker.WorkerHandler_ID,
-                                                         m_Process.exitcode, "ABORTED")
+                                                           m_Process.exitcode, "ABORTED")
                                         m_Job.failed_jobs = m_Job.failed_jobs + 1
                                         m_Job.finished_jobs = m_Job.finished_jobs + 1
                                         m_Job.active_jobs = m_Job.active_jobs - 1
@@ -933,8 +933,12 @@ class JOBManager(object):
                 m_db_cursor.execute(m_SQL, parameters=m_Data)
             m_db_cursor.close()
             self.MetaConn.commit()
-        except Exception as ex:
-            print("Internal error:: perf file write not complete. " + repr(ex))
+        except Exception:
+            print("Internal error:: Save Job write not complete. ")
+            import traceback
+            if "SQLCLI_DEBUG" in os.environ:
+                print('traceback.print_exc():\n%s' % traceback.print_exc())
+                print('traceback.format_exc():\n%s' % traceback.format_exc())
         finally:
             self.MetaLockHandler.release()
 
@@ -970,13 +974,13 @@ class JOBManager(object):
         # 如果输入的参数为all，则显示全部的JOB信息
         if p_szjobName.lower() == "all":
             m_Header = ["job_name", "tag", "status", "active_jobs", "failed_jobs", "finished_jobs",
-                        "submit_time", "start_time", "end_time"]
+                        "submit_time", "start_time", "end_time", "message"]
             m_Result = []
             for m_JOB in self.getAllJobs():
                 m_Result.append([m_JOB.getJobName(), m_JOB.getTag(), m_JOB.getStatus(), m_JOB.getActiveJobs(),
                                  m_JOB.getFailedJobs(), m_JOB.getFinishedJobs(),
                                  str(m_JOB.getSubmitTime()), str(m_JOB.getStartTime()),
-                                 str(m_JOB.getEndTime())])
+                                 str(m_JOB.getEndTime()), str(m_JOB.getErrorMessage())])
             return None, m_Result, m_Header, None, "Total [" + str(len(m_Result)) + "] Jobs."
         else:
             strMessages = ""
@@ -1062,7 +1066,7 @@ class JOBManager(object):
                 bAllProcessFinished = True
                 for m_Job in self.getAllJobs():
                     if m_Job.getStatus() not in \
-                            ["Submitted", "FINISHED", "SHUTDOWNED", "ABORTED"]:
+                            ["Submitted", "FINISHED", "SHUTDOWNED", "ABORTED", "FAILED"]:
                         bAllProcessFinished = False
                         time.sleep(3)
                         continue
@@ -1331,92 +1335,82 @@ class JOBManager(object):
         m_szSQL = p_szCommand.strip()
 
         # 创建新的JOB
-        matchObj = re.match(r"job\s+create\s+(.*)(\s+)?$",
-                            m_szSQL, re.IGNORECASE | re.DOTALL)
-        if matchObj:
-            m_ParameterList = str(matchObj.group(1)).strip().split()
+        match_obj = re.match(r"job\s+create\s+(.*)(\s+)?$", m_szSQL, re.IGNORECASE | re.DOTALL)
+        if match_obj:
+            m_ParameterList = str(match_obj.group(1)).strip().split()
             # 第一个参数是JOBNAME
             m_JobName = m_ParameterList[0].strip()
             m_Job = self.createjob(m_JobName)
             m_ParameterList = m_ParameterList[1:]
-            for m_nPos in range(0, len(m_ParameterList) // 2):
-                m_ParameterName = m_ParameterList[2*m_nPos]
-                m_ParameterValue = m_ParameterList[2 * m_nPos + 1]
+            for pos in range(0, len(m_ParameterList) // 2):
+                m_ParameterName = m_ParameterList[2*pos]
+                m_ParameterValue = m_ParameterList[2 * pos + 1]
                 m_Job.setjob(m_ParameterName, m_ParameterValue)
             self.SaveJob(m_Job)
             return None, None, None, None, "JOB [" + m_JobName + "] create successful."
 
         # 显示当前的JOB
-        matchObj = re.match(r"job\s+show\s+(.*)$",
-                            m_szSQL, re.IGNORECASE | re.DOTALL)
-        if matchObj:
-            m_JobName = str(matchObj.group(1)).strip()
+        match_obj = re.match(r"job\s+show\s+(.*)$", m_szSQL, re.IGNORECASE | re.DOTALL)
+        if match_obj:
+            m_JobName = str(match_obj.group(1)).strip()
             return self.showjob(m_JobName)
 
         # 设置JOB的各种参数
-        matchObj = re.match(r"job\s+set\s+(.*)\s+(.*)\s+(.*)$",
-                            m_szSQL, re.IGNORECASE | re.DOTALL)
-        if matchObj:
-            m_JobName = str(matchObj.group(1)).strip()
-            m_ParameterName = str(matchObj.group(2)).strip()
-            m_ParameterValue = str(matchObj.group(3)).strip()
+        match_obj = re.match(r"job\s+set\s+(.*)\s+(.*)\s+(.*)$", m_szSQL, re.IGNORECASE | re.DOTALL)
+        if match_obj:
+            m_JobName = str(match_obj.group(1)).strip()
+            m_ParameterName = str(match_obj.group(2)).strip()
+            m_ParameterValue = str(match_obj.group(3)).strip()
             m_Job = self.getJobByName(m_JobName)
             m_Job.setjob(m_ParameterName, m_ParameterValue)
             self.SaveJob(m_Job)
             return None, None, None, None, "JOB [" + m_JobName + "] set successful."
 
         # 启动JOB
-        matchObj = re.match(r"job\s+start\s+(.*)$",
-                            m_szSQL, re.IGNORECASE | re.DOTALL)
-        if matchObj:
-            m_JobName = str(matchObj.group(1)).strip()
+        match_obj = re.match(r"job\s+start\s+(.*)$", m_szSQL, re.IGNORECASE | re.DOTALL)
+        if match_obj:
+            m_JobName = str(match_obj.group(1)).strip()
             nJobStarted = self.startjob(m_JobName)
             return None, None, None, None, "Total [" + str(nJobStarted) + "] jobs started."
 
         # 等待JOB完成
-        matchObj = re.match(r"job\s+wait\s+(.*)$",
-                            m_szSQL, re.IGNORECASE | re.DOTALL)
-        if matchObj:
-            m_JobName = str(matchObj.group(1)).strip()
+        match_obj = re.match(r"job\s+wait\s+(.*)$", m_szSQL, re.IGNORECASE | re.DOTALL)
+        if match_obj:
+            m_JobName = str(match_obj.group(1)).strip()
             self.waitjob(m_JobName)
             return None, None, None, None, "All jobs [" + m_JobName + "] finished."
 
         # 等待JOB的检查点完成
-        matchObj = re.match(r"job\s+timer\s+(.*)$",
-                            m_szSQL, re.IGNORECASE | re.DOTALL)
-        if matchObj:
-            m_TimerPoint = str(matchObj.group(1)).strip()
+        match_obj = re.match(r"job\s+timer\s+(.*)$", m_szSQL, re.IGNORECASE | re.DOTALL)
+        if match_obj:
+            m_TimerPoint = str(match_obj.group(1)).strip()
             self.waitjobtimer(m_TimerPoint)
             return None, None, None, None, "TimerPoint [" + m_TimerPoint + "] has arrived."
 
         # 终止JOB作业
-        matchObj = re.match(r"job\s+shutdown\s+(.*)$",
-                            m_szSQL, re.IGNORECASE | re.DOTALL)
-        if matchObj:
-            m_JobName = str(matchObj.group(1)).strip()
+        match_obj = re.match(r"job\s+shutdown\s+(.*)$", m_szSQL, re.IGNORECASE | re.DOTALL)
+        if match_obj:
+            m_JobName = str(match_obj.group(1)).strip()
             nJobShutdowned = self.shutdownjob(m_JobName)
             return None, None, None, None, "Total [" + str(nJobShutdowned) + "] jobs shutdowned."
 
         # 放弃JOB作业
-        matchObj = re.match(r"job\s+abort\s+(.*)$",
-                            m_szSQL, re.IGNORECASE | re.DOTALL)
-        if matchObj:
-            m_JobName = str(matchObj.group(1)).strip()
+        match_obj = re.match(r"job\s+abort\s+(.*)$", m_szSQL, re.IGNORECASE | re.DOTALL)
+        if match_obj:
+            m_JobName = str(match_obj.group(1)).strip()
             nJobAborted = self.abortjob(m_JobName)
             return None, None, None, None, "Total [" + str(nJobAborted) + "] jobs aborted."
 
         # 注册当前Worker到指定的JOB上
-        matchObj = re.match(r"job\s+register\s+worker\s+to\s+(.*)$",
-                            m_szSQL, re.IGNORECASE | re.DOTALL)
-        if matchObj:
-            m_JobName = str(matchObj.group(1)).strip()
+        match_obj = re.match(r"job\s+register\s+worker\s+to\s+(.*)$", m_szSQL, re.IGNORECASE | re.DOTALL)
+        if match_obj:
+            m_JobName = str(match_obj.group(1)).strip()
             self.registerjob(m_JobName)
             return None, None, None, None, "Register worker to Job [" + str(m_JobName) + "] Successful."
 
         # 取消当前Worker的注册
-        matchObj = re.match(r"job\s+unregister\s+worker(\s+)?$",
-                            m_szSQL, re.IGNORECASE | re.DOTALL)
-        if matchObj:
+        match_obj = re.match(r"job\s+unregister\s+worker(\s+)?$", m_szSQL, re.IGNORECASE | re.DOTALL)
+        if match_obj:
             self.unregisterjob()
             return None, None, None, None, "Worker has been unregistered Successful."
 
